package com.smppw.analysis.domain.service;

import com.smppw.analysis.domain.dataobject.MonetaryFundProfitDO;
import com.smppw.analysis.domain.dataobject.PrivatelyFundBaseInfoDo;
import com.smppw.analysis.domain.dataobject.PubliclyFundBaseInfoDo;
import com.smppw.common.pojo.ValueLabelVO;
import com.smppw.common.pojo.enums.Frequency;

import java.util.List;
import java.util.Map;

/**
 * @author wangzaijun
 * @date 2023/8/3 15:42
 * @description 基础信息服务
 */
public interface BaseInfoService {
    /**
     * 常用指数
     *
     * @return /
     */
    List<ValueLabelVO> getCommonIndexList();

    /**
     * 获取标的类型
     *
     * @param secId /
     * @return /
     */
    String getSecType(String secId);

    /**
     * 获取类型与标的的对应关系
     *
     * @param secIdList 标的集合
     * @return /
     */
    Map<String, List<String>> getTypeSecMap(List<String> secIdList);

    /**
     * 获取标的id和名称映射关系
     *
     * @param allSecIdList 标的id集合
     * @return /
     */
    Map<String, String> querySecName(List<String> allSecIdList);

    /**
     * 湖区标的净值频率
     *
     * @param secId 标的id
     * @return /
     */
    Frequency getNavFrequency(String secId);

    /**
     * 获取货币基金业绩列表
     *
     * @param fundId 基金id
     * @return /
     */
    List<MonetaryFundProfitDO> queryMonetaryFund(String fundId);

    /**
     * 获取私募基金的基本信息
     *
     * @param fundId 基金id
     * @return 私募基金的基本信息
     */
    PrivatelyFundBaseInfoDo listPrivatelyFundInfo(String fundId);

    /**
     * 获取公募基金的基本信息
     *
     * @param fundId 基金id
     * @return 私募基金的基本信息
     */
    PubliclyFundBaseInfoDo listPublicFundInfo(String fundId);
}
